@@ -23,6 +23,7 @@ from pyinstrument.util import (
 from pyinstrument.vendor import appdirs, keypath
 
 # pyright: strict
+# pyright: reportUnknownMemberType=false
 
 
 def main():
@@ -31,7 +32,7 @@ def main():
         v=pyinstrument.__version__,
         pyv=sys.version_info,
     )
-    parser = optparse.OptionParser(usage=usage, version=version_string)
+    parser: Any = optparse.OptionParser(usage=usage, version=version_string)
     parser.allow_interspersed_args = False
 
     def store_and_consume_remaining(
@@ -248,6 +249,16 @@ def main():
         ),
         default=0.001,
     )
+    parser.add_option(
+        "",
+        "--use-timing-thread",
+        dest="use_timing_thread",
+        action="store_true",
+        help=(
+            "Use a separate thread to time the interval between stack samples. "
+            "This can reduce the overhead of sampling on some systems."
+        ),
+    )
 
     # parse the options
 
@@ -298,6 +309,8 @@ def main():
         f = sys.stdout
         should_close_f_after_writing = False
 
+    inner_exception = None
+
     # create the renderer
 
     try:
@@ -357,14 +370,19 @@ def main():
         # because it will always be capturing the whole program, we never want
         # any execution to be <out-of-context>, and it avoids duplicate
         # profiler errors.
-        profiler = Profiler(interval=options.interval, async_mode="disabled")
-        profiler.start()
+        profiler = Profiler(
+            interval=options.interval,
+            async_mode="disabled",
+            use_timing_thread=options.use_timing_thread,
+        )
+
+        profiler.start(target_description=f'Program: {" ".join(argv)}')
 
         try:
             sys.argv[:] = argv
             exec(code, globs, None)
-        except (SystemExit, KeyboardInterrupt):
-            pass
+        except (SystemExit, KeyboardInterrupt) as e:
+            inner_exception = e
         finally:
             sys.argv[:] = old_argv
 
@@ -385,6 +403,11 @@ def main():
         print("    pyinstrument --load-prev %s [options]" % report_identifier)
         print("")
 
+    if inner_exception:
+        # If the script raised an exception, re-raise it now to resume
+        # the normal Python exception handling (printing the traceback, etc.)
+        raise inner_exception
+
 
 def compute_render_options(
     options: CommandLineOptions, renderer_class: type[renderers.Renderer], output_file: TextIO
@@ -600,6 +623,7 @@ class CommandLineOptions:
     renderer: str | None
     timeline: bool
     interval: float
+    use_timing_thread: bool | None
 
 
 class ValueWithRemainingArgs:
